import { createElement } from "../utils/createElement.js";
export class SVGInstance {
    constructor(tagName) {
        this.childInstances = [];
        this.element = createElement(tagName);
    }
    appendInstance(instance) {
        this.childInstances.push(instance);
        this.element.appendChild(instance.element);
        return this;
    }
    id(id) {
        if (typeof id === "string") {
            this.element.id = id;
            return this;
        }
        return this.element.id;
    }
    get innerHTML() {
        return this.element.innerHTML;
    }
    get outerHTML() {
        return this.element.outerHTML;
    }
    addClass(classNameOrClassNames) {
        if (typeof classNameOrClassNames === "string") {
            this.element.classList.add(classNameOrClassNames);
        }
        else if (Array.isArray(classNameOrClassNames)) {
            classNameOrClassNames.forEach(className => this.element.classList.add(className));
        }
        return this;
    }
    removeClass(classNameOrClassNames) {
        if (typeof classNameOrClassNames === "string") {
            this.element.classList.remove(classNameOrClassNames);
        }
        else if (Array.isArray(classNameOrClassNames)) {
            classNameOrClassNames.forEach(className => this.element.classList.remove(className));
        }
        return this;
    }
    hasClass(className) {
        return this.element.classList.contains(className);
    }
    attr(attributeNameOrAttributeObjectOrUndefined, valueOrUndefined) {
        //-- Convert numeric strings to numbers
        const attributes = Object.entries(this.element.attributes).reduce((previous, [key, value]) => ({ ...previous, [key]: isNaN(+value) ? value : +value }), {});
        if (typeof attributeNameOrAttributeObjectOrUndefined === "undefined") {
            return attributes;
        }
        else if (typeof attributeNameOrAttributeObjectOrUndefined === "object") {
            if (Array.isArray(attributeNameOrAttributeObjectOrUndefined)) {
                return Object.fromEntries(Object.entries(attributes).filter(([key, value]) => attributeNameOrAttributeObjectOrUndefined.includes(key)));
            }
            else {
                Object.keys(attributeNameOrAttributeObjectOrUndefined).forEach(key => { this.element.setAttribute(key, attributeNameOrAttributeObjectOrUndefined[key] + ""); });
                return this;
            }
        }
        else if (typeof attributeNameOrAttributeObjectOrUndefined === "string") {
            if (typeof valueOrUndefined === "undefined") {
                return attributes[attributeNameOrAttributeObjectOrUndefined] ?? null;
            }
            else {
                this.element.setAttribute(attributeNameOrAttributeObjectOrUndefined, valueOrUndefined + "");
                return this;
            }
        }
        return null;
    }
    removeAttr(attributeName) {
        this.element.removeAttribute(attributeName);
        return this;
    }
}
//# sourceMappingURL=SVGInstance.js.map